==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/PanePinnedEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { UnpinnedLocation_$type } from "./UnpinnedLocation";
/**
 * @hidden
 */
export let PanePinnedEventArgsDetail = /*@__PURE__*/ (() => {
    class PanePinnedEventArgsDetail extends Base {
        constructor() {
            super(...arguments);
            this.d = new WCNativeHelper();
            this.g = null;
        }
        get e() {
            return this.d;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.d.n = this.g;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.e.l("sourcePane", (a) => new ContentPane());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.e.u("sourcePane", value_);
        }
        get a() {
            let ret_ = this.e.l("panes", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.e.u("panes", value_);
        }
        get f() {
            let ret_ = this.e.m("newValue");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.e.u("newValue", value_);
        }
        get c() {
            let ret_ = this.e.m("location");
            ret_ = enumGetBox(UnpinnedLocation_$type, EnumUtil.getEnumValue(UnpinnedLocation_$type, this.e.f(UnpinnedLocation_$type, ret_)));
            return EnumUtil.getEnumValue(UnpinnedLocation_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(UnpinnedLocation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("location", value_);
        }
    }
    PanePinnedEventArgsDetail.$t = /*@__PURE__*/ markType(PanePinnedEventArgsDetail, 'PanePinnedEventArgsDetail');
    return PanePinnedEventArgsDetail;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/PanePinnedEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { UnpinnedLocation_$type } from "./UnpinnedLocation";
/**
 * @hidden
 */
export let PanePinnedEventArgsDetail = /*@__PURE__*/ (() => {
    class PanePinnedEventArgsDetail extends Base {
        constructor() {
            super(...arguments);
            this.d = new WCNativeHelper();
            this.g = null;
        }
        get e() {
            return this.d;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.d.o = this.g;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.e.m("sourcePane", (a) => new ContentPane());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.e.v("sourcePane", value_);
        }
        get a() {
            let ret_ = this.e.m("panes", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.e.v("panes", value_);
        }
        get f() {
            let ret_ = this.e.n("newValue");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.e.v("newValue", value_);
        }
        get c() {
            let ret_ = this.e.n("location");
            ret_ = enumGetBox(UnpinnedLocation_$type, EnumUtil.getEnumValue(UnpinnedLocation_$type, this.e.f(UnpinnedLocation_$type, ret_)));
            return EnumUtil.getEnumValue(UnpinnedLocation_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(UnpinnedLocation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("location", value_);
        }
    }
    PanePinnedEventArgsDetail.$t = /*@__PURE__*/ markType(PanePinnedEventArgsDetail, 'PanePinnedEventArgsDetail');
    return PanePinnedEventArgsDetail;
})();
